Function slice_diff_patch::diff_diff
source · [−]Expand description
Calculate the diff between a and b via diff::slice and convert to a Vec<Change>.
Calculate the diff between a and b via diff::slice and convert to a Vec<Change>.