Function slice_diff_patch::wu_diff
source · [−]Expand description
Calculate the diff between a and b via wu_diff::diff and convert to a Vec<Change>.
Calculate the diff between a and b via wu_diff::diff and convert to a Vec<Change>.